!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: M. Chiesa, J.N. Lang                   |            !
!        | `---' | UFO date: No date                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2019-05-07 19:53             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1204
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: FFaV0 = 4
  integer, parameter :: FFaV1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVVV0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: UVUa0 = 12
  integer, parameter :: FaF0 = 13
  integer, parameter :: FaF1 = 14
  integer, parameter :: VFaF0 = 15
  integer, parameter :: VFaF1 = 16
  integer, parameter :: VVV0 = 17
  integer, parameter :: VVV1 = 18
  integer, parameter :: VVV2 = 19
  integer, parameter :: VVV3 = 20
  integer, parameter :: VVV4 = 21
  integer, parameter :: VVV5 = 22
  integer, parameter :: VVV6 = 23
  integer, parameter :: VVV7 = 24
  integer, parameter :: VVV8 = 25
  integer, parameter :: VVV9 = 26
  integer, parameter :: VVV10 = 27
  integer, parameter :: VVV11 = 28
  integer, parameter :: VVV12 = 29
  integer, parameter :: VVV13 = 30
  integer, parameter :: VVV14 = 31
  integer, parameter :: VVV15 = 32
  integer, parameter :: VVV16 = 33
  integer, parameter :: VVV17 = 34
  integer, parameter :: VVV18 = 35
  integer, parameter :: VVV19 = 36
  integer, parameter :: FSFa0 = 37
  integer, parameter :: FSFa1 = 38
  integer, parameter :: FSFa2 = 39
  integer, parameter :: VVS0 = 40
  integer, parameter :: VVS1 = 41
  integer, parameter :: VVS2 = 42
  integer, parameter :: VVS3 = 43
  integer, parameter :: VVS4 = 44
  integer, parameter :: VVS5 = 45
  integer, parameter :: VVS6 = 46
  integer, parameter :: VVS7 = 47
  integer, parameter :: VVS8 = 48
  integer, parameter :: VVS9 = 49
  integer, parameter :: FaVF0 = 50
  integer, parameter :: FaVF1 = 51
  integer, parameter :: UaVU0 = 52
  integer, parameter :: VSVS0 = 53
  integer, parameter :: FVFa0 = 54
  integer, parameter :: FVFa1 = 55
  integer, parameter :: UaSU0 = 56
  integer, parameter :: USUa0 = 57
  integer, parameter :: VV0 = 58
  integer, parameter :: VV1 = 59
  integer, parameter :: VV2 = 60
  integer, parameter :: SVSV0 = 61
  integer, parameter :: FaFS0 = 62
  integer, parameter :: FaFS1 = 63
  integer, parameter :: FaFS2 = 64
  integer, parameter :: FaFV0 = 65
  integer, parameter :: FaFV1 = 66
  integer, parameter :: SSSS0 = 67
  integer, parameter :: SFFa0 = 68
  integer, parameter :: SFFa1 = 69
  integer, parameter :: SFFa2 = 70
  integer, parameter :: VUUa0 = 71
  integer, parameter :: SFaF0 = 72
  integer, parameter :: SFaF1 = 73
  integer, parameter :: SFaF2 = 74
  integer, parameter :: SVV0 = 75
  integer, parameter :: SVV1 = 76
  integer, parameter :: SVV2 = 77
  integer, parameter :: SVV3 = 78
  integer, parameter :: SVV4 = 79
  integer, parameter :: SVV5 = 80
  integer, parameter :: SVV6 = 81
  integer, parameter :: SVV7 = 82
  integer, parameter :: FaSF0 = 83
  integer, parameter :: FaSF1 = 84
  integer, parameter :: FaSF2 = 85
  integer, parameter :: SVS0 = 86
  integer, parameter :: SVS1 = 87
  integer, parameter :: FFa0 = 88
  integer, parameter :: FFa1 = 89
  integer, parameter :: VSS0 = 90
  integer, parameter :: VSS1 = 91
  integer, parameter :: VSV0 = 92
  integer, parameter :: VSV1 = 93
  integer, parameter :: VSV2 = 94
  integer, parameter :: VSV3 = 95
  integer, parameter :: VSV4 = 96
  integer, parameter :: VSV5 = 97
  integer, parameter :: VSV6 = 98
  integer, parameter :: VSV7 = 99
  integer, parameter :: VSV8 = 100
  integer, parameter :: VSV9 = 101
  integer, parameter :: SS0 = 102
  integer, parameter :: SS1 = 103
  integer, parameter :: SSVV0 = 104
  integer, parameter :: SSV0 = 105
  integer, parameter :: SSV1 = 106
  integer, parameter :: SSS0 = 107
  integer, parameter :: VUaU0 = 108
  integer, parameter :: VSSV0 = 109
  integer, parameter :: UaUS0 = 110
  integer, parameter :: VFFa0 = 111
  integer, parameter :: VFFa1 = 112
  integer, parameter :: SUaU0 = 113
  integer, parameter :: UaUV0 = 114
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:114) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0&
                                              , 1, -1, -1, 1, 1, 2, 1, 2, 2, 2 &
                                              , 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2&
                                              , 2, 2, 2, 2, 1, 1, 1, 3, 2, 0, 2&
                                              , 3, 2, 2, 3, 3, 1, 1, 1, 1, 0, 1&
                                              , 1, 0, 0, -1, -1, -1, 0, 0, 0, 0&
                                              , 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2&
                                              , 0, 3, 1, 2, 3, 3, 3, 1, 1, 1, 2&
                                              , 1, -1, -1, 2, 1, 2, 1, 0, 2, 1 &
                                              , 1, 1, 2, 1, 2, -1, -1, 0, 2, 1 &
                                              , 0, 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:114) :: ff_ids = (/0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                        , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0/)
  integer, dimension(1:114) :: recola_base = (/5, 7, 9, 15, 17, -2, -11, 1, 161&
                                             , 1, -4, 165, 0, 0, 53, 58, 0, 12 &
                                             , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                             , 0, 0, 0, 0, 0, 0, 0, 21, 27, 25 &
                                             , 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 51&
                                             , 57, 166, -3, 35, 31, 1, 1, 0, 0 &
                                             , 0, -14, 6, 10, 8, 16, 18, -1, 23&
                                             , 26, 28, 163, 43, 46, 48, 0, 13, &
                                             0, 0, 0, 0, 0, 0, 41, 47, 45, 0, 3&
                                             , 0, 0, 0, 4, 0, 0, 14, 0, 0, 0, 0&
                                             , 0, 0, 0, 0, 0, -12, 0, 11, 1,   &
                                             162, -13, 1, 36, 33, 1, 164/)
  integer, dimension(1:114) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0/)
  character(len=*), parameter :: model_timestamp = "Tue May  7 18:52:06 2019"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function get_fourfermion_id_mdl(l_id) result(ret_ffid)
      integer, intent(in) :: l_id
      integer :: ret_ffid
      ret_ffid = ff_ids(l_id)
    end function get_fourfermion_id_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(2399)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 940, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 769, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 183, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 101, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 373, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 554, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 520, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1117, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 114, check)
      call createCurrent(P_t, P_tAnti, P_A, 912, check)
      call createCurrent(P_c, P_G0, P_cAnti, 593, check)
      call createCurrent(P_H, P_t, P_tAnti, 904, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 949, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 475, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 52, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 898, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 32, check)
      call createCurrent(P_Z, P_bAnti, P_b, 767, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 674, check)
      call createCurrent(P_G0, P_cAnti, P_c, 836, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 14, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 116, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 499, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 68, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 595, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 743, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 45, check)
      call createCurrent(P_Z, P_dAnti, P_d, 371, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 344, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1149, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 685, check)
      call createCurrent(P_muPlus, P_muMinus, 1113, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 117, check)
      call createCurrent(P_bAnti, P_b, P_Z, 633, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 927, check)
      call createCurrent(P_G0, P_G0, P_Z, 728, check)
      call createCurrent(P_G0, P_uAnti, P_u, 361, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 729, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 909, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 277, check)
      call createCurrent(P_A, P_c, P_cAnti, 190, check)
      call createCurrent(P_s, P_sAnti, P_H, 913, check)
      call createCurrent(P_t, P_tAnti, P_G0, 98, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1119, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 1054, check)
      call createCurrent(P_H, P_G0, P_G0, 1088, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 375, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 809, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 362, check)
      call createCurrent(P_A, P_G0, P_H, 973, check)
      call createCurrent(P_A, P_uAnti, P_u, 121, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 345, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 169, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 821, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 514, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 1062, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1161, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 85, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 551, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 622, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 103, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 207, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 317, check)
      call createCurrent(P_H, P_H, 1135, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1128, check)
      call createCurrent(P_uAnti, P_u, 1107, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 891, check)
      call createCurrent(P_sAnti, P_g, P_s, 328, check)
      call createCurrent(P_b, P_A, P_bAnti, 48, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 530, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 354, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 534, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 611, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1148, check)
      call createCurrent(P_d, P_Z, P_dAnti, 350, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 788, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 598, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 737, check)
      call createCurrent(P_A, P_dAnti, P_d, 1056, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 805, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 741, check)
      call createCurrent(P_Z, P_A, P_Z, 222, check)
      call createCurrent(P_Z, P_u, P_uAnti, 740, check)
      call createCurrent(P_sAnti, P_s, 1100, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 625, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 718, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 850, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 46, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 370, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 298, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 353, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 35, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 77, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 699, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 844, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 448, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 574, check)
      call createCurrent(P_g, P_c, P_cAnti, 276, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 158, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 452, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 823, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 78, check)
      call createCurrent(P_G0, P_A, P_A, 807, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1143, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 562, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 645, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 278, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 649, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1118, check)
      call createCurrent(P_sAnti, P_Z, P_s, 730, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 472, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 349, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 601, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1131, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 1031, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 963, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 137, check)
      call createCurrent(P_dAnti, P_d, 1103, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 857, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 600, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 669, check)
      call createCurrent(P_u, P_uAnti, P_G0, 811, check)
      call createCurrent(P_s, P_A, P_sAnti, 846, check)
      call createCurrent(P_g, P_H, P_g, 1146, check)
      call createCurrent(P_ePlus, P_eMinus, 1156, check)
      call createCurrent(P_d, P_G0, P_dAnti, 1028, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 566, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 722, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1185, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1129, check)
      call createCurrent(P_t, P_G0, P_tAnti, 67, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 265, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 753, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 124, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 570, check)
      call createCurrent(P_H, P_G0, P_A, 398, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 1023, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 894, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 295, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 315, check)
      call createCurrent(P_cAnti, P_g, P_c, 980, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 785, check)
      call createCurrent(P_A, P_cAnti, P_c, 900, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 84, check)
      call createCurrent(P_G0, P_H, P_Z, 680, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 407, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 444, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 26, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 1043, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 147, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 673, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 791, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 938, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 493, check)
      call createCurrent(P_H, P_H, P_Z, 854, check)
      call createCurrent(P_cAnti, P_Z, P_c, 195, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 133, check)
      call createCurrent(P_g, P_tAnti, P_t, 59, check)
      call createCurrent(P_GPlus, P_GMinus, 1124, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1168, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 267, check)
      call createCurrent(P_t, P_H, P_tAnti, 1042, check)
      call createCurrent(P_cAnti, P_A, P_c, 99, check)
      call createCurrent(P_g, P_g, P_H, 1154, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 199, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 697, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 549, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 451, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 149, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 591, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 721, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 731, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 247, check)
      call createCurrent(P_uAnti, P_u, P_H, 1007, check)
      call createCurrent(P_H, P_H, P_H, P_H, 1004, check)
      call createCurrent(P_Z, P_G0, P_H, 705, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 415, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 426, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 115, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1202, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 376, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 168, check)
      call createCurrent(P_t, P_Z, P_tAnti, 262, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 301, check)
      call createCurrent(P_G0, P_dAnti, P_d, 1020, check)
      call createCurrent(P_t, P_g, P_tAnti, 159, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1164, check)
      call createCurrent(P_s, P_Z, P_sAnti, 1052, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 930, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 889, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 573, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 597, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1055, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 815, check)
      call createCurrent(P_H, P_cAnti, P_c, 196, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 714, check)
      call createCurrent(P_bAnti, P_b, P_G0, 322, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 603, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 1040, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 329, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 476, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 979, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 779, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 455, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 235, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 87, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 74, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 414, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 651, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 713, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 202, check)
      call createCurrent(P_G0, P_u, P_uAnti, 1096, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 309, check)
      call createCurrent(P_H, P_dAnti, P_d, 585, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 71, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 439, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 763, check)
      call createCurrent(P_H, P_uAnti, P_u, 139, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 204, check)
      call createCurrent(P_u, P_A, P_uAnti, 1018, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 153, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 777, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 748, check)
      call createCurrent(P_H, P_g, P_g, 1137, check)
      call createCurrent(P_uAnti, P_G0, P_u, 657, check)
      call createCurrent(P_A, P_u, P_uAnti, 935, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 1027, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 470, check)
      call createCurrent(P_G0, P_c, P_cAnti, 658, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 883, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1171, check)
      call createCurrent(P_dAnti, P_d, P_Z, 79, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 9, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 608, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 446, check)
      call createCurrent(P_b, P_bAnti, P_G0, 537, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 219, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 783, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 457, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 104, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 727, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 919, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 851, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 650, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 819, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 985, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 229, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1194, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 875, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 238, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 937, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 1009, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 491, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 1049, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 474, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 60, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 459, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1022, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 304, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 113, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 281, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1172, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 994, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 906, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 869, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 677, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 245, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1037, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 510, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 224, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 613, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 27, check)
      call createCurrent(P_sAnti, P_s, P_H, 461, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 910, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 626, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 512, check)
      call createCurrent(P_g, P_u, P_uAnti, 88, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 890, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 621, check)
      call createCurrent(P_Z, P_Z, P_Z, 445, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 260, check)
      call createCurrent(P_d, P_A, P_dAnti, 559, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1114, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 558, check)
      call createCurrent(P_Z, P_uAnti, P_u, 248, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 542, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 418, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1195, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 325, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 186, check)
      call createCurrent(P_A, P_Z, P_G0, 33, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 710, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 177, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 926, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 227, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 635, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 264, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 916, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 1024, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 609, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 198, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 1085, check)
      call createCurrent(P_dAnti, P_g, P_d, 51, check)
      call createCurrent(P_Z, P_A, P_G0, 610, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 382, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 1030, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 306, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 526, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 431, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 383, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 917, check)
      call createCurrent(P_c, P_cAnti, P_A, 331, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 661, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 561, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 582, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 1035, check)
      call createCurrent(P_sAnti, P_s, P_A, 15, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 404, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 618, check)
      call createCurrent(P_s, P_sAnti, 1099, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 478, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 747, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 529, check)
      call createCurrent(P_H, P_H, P_A, 602, check)
      call createCurrent(P_H, P_sAnti, P_s, 939, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1130, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 711, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 1051, check)
      call createCurrent(P_A, P_G0, P_Z, 305, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 53, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 518, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 97, check)
      call createCurrent(P_b, P_bAnti, P_Z, 435, check)
      call createCurrent(P_g, P_sAnti, P_s, 646, check)
      call createCurrent(P_tAnti, P_t, P_A, 772, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 241, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 623, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 872, check)
      call createCurrent(P_u, P_uAnti, P_H, 11, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 285, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1152, check)
      call createCurrent(P_sAnti, P_G0, P_s, 901, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 230, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 852, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 695, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 173, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 486, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 73, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 691, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 734, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 8, check)
      call createCurrent(P_G0, P_bAnti, P_b, 557, check)
      call createCurrent(P_A, P_d, P_dAnti, 319, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 588, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 92, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1201, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 86, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 342, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 70, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 1034, check)
      call createCurrent(P_H, P_H, P_H, 348, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 386, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 20, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 653, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 188, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 833, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 761, check)
      call createCurrent(P_dAnti, P_A, P_d, 377, check)
      call createCurrent(P_d, P_dAnti, P_g, 6, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 644, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 798, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 799, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 287, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1170, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 130, check)
      call createCurrent(P_u, P_uAnti, P_Z, 700, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 838, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 157, check)
      call createCurrent(P_A, P_sAnti, P_s, 655, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 152, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1175, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1133, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 335, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 313, check)
      call createCurrent(P_sAnti, P_A, P_s, 0, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 355, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1116, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 62, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1010, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 351, check)
      call createCurrent(P_A, P_t, P_tAnti, 513, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 90, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 1084, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1184, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1132, check)
      call createCurrent(P_Z, P_b, P_bAnti, 405, check)
      call createCurrent(P_d, P_dAnti, P_Z, 902, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 818, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 487, check)
      call createCurrent(P_dAnti, P_H, P_d, 321, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1138, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 160, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 417, check)
      call createCurrent(P_Z, P_A, P_A, 280, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 954, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 18, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 284, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1176, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 885, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1187, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1095, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1162, check)
      call createCurrent(P_GMinus, P_GPlus, 1127, check)
      call createCurrent(P_A, P_A, P_G0, 982, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1193, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 828, check)
      call createCurrent(P_tAnti, P_H, P_t, 786, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 232, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1111, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 654, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 112, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 688, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 411, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 1014, check)
      call createCurrent(P_c, P_g, P_cAnti, 105, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 37, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 745, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 832, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 959, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 666, check)
      call createCurrent(P_c, P_cAnti, P_Z, 522, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1139, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 234, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 956, check)
      call createCurrent(P_uAnti, P_u, P_g, 357, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 640, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1189, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 110, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 892, check)
      call createCurrent(P_t, P_tAnti, 1108, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 323, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 706, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 25, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 81, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 1060, check)
      call createCurrent(P_s, P_g, P_sAnti, 1071, check)
      call createCurrent(P_tAnti, P_t, 1109, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 533, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 974, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 834, check)
      call createCurrent(P_sAnti, P_H, P_s, 63, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 660, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 996, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 480, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 977, check)
      call createCurrent(P_dAnti, P_Z, P_d, 592, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 259, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 473, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 210, check)
      call createCurrent(P_G0, P_s, P_sAnti, 519, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1115, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 479, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 758, check)
      call createCurrent(P_G0, P_Z, P_G0, 395, check)
      call createCurrent(P_Z, P_s, P_sAnti, 1041, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 605, check)
      call createCurrent(P_A, P_A, P_Z, 290, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 492, check)
      call createCurrent(P_b, P_bAnti, P_A, 687, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 294, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 390, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 193, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 341, check)
      call createCurrent(P_tAnti, P_t, P_Z, 467, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 668, check)
      call createCurrent(P_g, P_d, P_dAnti, 966, check)
      call createCurrent(P_uAnti, P_u, P_G0, 976, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 468, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 548, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 179, check)
      call createCurrent(P_A, P_Z, P_A, 125, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 138, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 288, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 712, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, 346, check)
      call createCurrent(P_g, P_g, P_g, P_g, 1050, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 888, check)
      call createCurrent(P_H, P_bAnti, P_b, 1021, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 310, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 521, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1121, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 1048, check)
      call createCurrent(P_A, P_H, P_G0, 257, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 571, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 425, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 134, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 50, check)
      call createCurrent(P_uAnti, P_A, P_u, 596, check)
      call createCurrent(P_H, P_A, P_H, 293, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1165, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1163, check)
      call createCurrent(P_t, P_tAnti, P_H, 111, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 365, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 724, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 336, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1125, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 456, check)
      call createCurrent(P_G0, P_H, P_G0, 132, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 810, check)
      call createCurrent(P_Z, P_G0, P_G0, 1001, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 391, check)
      call createCurrent(P_uAnti, P_H, P_u, 816, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 440, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 965, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 764, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 808, check)
      call createCurrent(P_A, P_Z, P_Z, 967, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 750, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 531, check)
      call createCurrent(P_H, P_d, P_dAnti, 978, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 126, check)
      call createCurrent(P_s, P_H, P_sAnti, 632, check)
      call createCurrent(P_cAnti, P_c, 1102, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 171, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1142, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 327, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 1067, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 986, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 471, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 462, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 925, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 862, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 863, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 579, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 842, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 708, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 1019, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 546, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 128, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 694, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 775, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 410, check)
      call createCurrent(P_g, P_g, 1106, check)
      call createCurrent(P_bAnti, P_A, P_b, 599, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 780, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 560, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 923, check)
      call createCurrent(P_G0, P_t, P_tAnti, 396, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 555, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 944, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 5, check)
      call createCurrent(P_dAnti, P_d, P_g, 671, check)
      call createCurrent(P_Z, P_A, 1191, check)
      call createCurrent(P_Z, P_Z, P_H, 540, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 145, check)
      call createCurrent(P_A, P_G0, P_G0, 683, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 441, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1197, check)
      call createCurrent(P_bAnti, P_g, P_b, 941, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 835, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 567, check)
      call createCurrent(P_sAnti, P_s, P_Z, 760, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 884, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 921, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 675, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 163, check)
      call createCurrent(P_u, P_uAnti, 1105, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 197, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 736, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 1097, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 663, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 225, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 1, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 106, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 865, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 34, check)
      call createCurrent(P_Z, P_Z, 1183, check)
      call createCurrent(P_s, P_sAnti, P_g, 2, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1174, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 704, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1112, check)
      call createCurrent(P_uAnti, P_Z, P_u, 848, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 437, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 38, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 242, check)
      call createCurrent(P_d, P_dAnti, P_G0, 946, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 918, check)
      call createCurrent(P_g, P_uAnti, P_u, 379, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 543, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 143, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 89, check)
      call createCurrent(P_G0, P_tAnti, P_t, 1044, check)
      call createCurrent(P_H, P_Z, P_Z, 990, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 7, check)
      call createCurrent(P_d, P_dAnti, 1110, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 552, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1192, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1169, check)
      call createCurrent(P_c, P_Z, P_cAnti, 1057, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 975, check)
      call createCurrent(P_Z, P_sAnti, P_s, 307, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 614, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 466, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 314, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 65, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 275, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 292, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 794, check)
      call createCurrent(P_H, P_G0, P_Z, 960, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 326, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 1029, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 463, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 64, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 421, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 676, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 91, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 436, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 620, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 837, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 246, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1000, check)
      call createCurrent(P_cAnti, P_c, P_H, 297, check)
      call createCurrent(P_WMinus, P_WPlus, 1126, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 606, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 364, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1199, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 450, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 495, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 993, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 1087, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 719, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 971, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 231, check)
      call createCurrent(P_G0, P_d, P_dAnti, 873, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 800, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 992, check)
      call createCurrent(P_bAnti, P_G0, P_b, 754, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 827, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 10, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 720, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 814, check)
      call createCurrent(P_H, P_Z, P_G0, 318, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 316, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 933, check)
      call createCurrent(P_c, P_cAnti, P_H, 953, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 96, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 187, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 789, check)
      call createCurrent(P_Z, P_cAnti, P_c, 501, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 544, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 429, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 166, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 692, check)
      call createCurrent(P_bAnti, P_Z, P_b, 270, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 969, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 545, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 216, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 107, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 696, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 374, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 577, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 22, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 1061, check)
      call createCurrent(P_cAnti, P_H, P_c, 94, check)
      call createCurrent(P_d, P_dAnti, P_A, 394, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 942, check)
      call createCurrent(P_A, P_Z, 1178, check)
      call createCurrent(P_s, P_G0, P_sAnti, 707, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 108, check)
      call createCurrent(P_G0, P_G0, P_H, 494, check)
      call createCurrent(P_G0, P_A, P_Z, 553, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 274, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 958, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 393, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 271, check)
      call createCurrent(P_cAnti, P_c, P_A, 170, check)
      call createCurrent(P_eMinus, P_ePlus, 1167, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 443, check)
      call createCurrent(P_u, P_uAnti, P_A, 416, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 82, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 1064, check)
      call createCurrent(P_c, P_cAnti, 1101, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 796, check)
      call createCurrent(P_H, P_A, P_Z, 1068, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 460, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 757, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 338, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 765, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 283, check)
      call createCurrent(P_s, P_sAnti, P_Z, 895, check)
      call createCurrent(P_WPlus, P_WMinus, 1159, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 1074, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 879, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 102, check)
      call createCurrent(P_bAnti, P_H, P_b, 667, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 83, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1190, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 490, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 40, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1120, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 964, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 1013, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 759, check)
      call createCurrent(P_g, P_s, P_sAnti, 217, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 496, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 172, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 690, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 1038, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 200, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 220, check)
      call createCurrent(P_b, P_bAnti, 1098, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 1075, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 756, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 1082, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1145, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 703, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 962, check)
      call createCurrent(P_uAnti, P_u, P_Z, 1092, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 442, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 787, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 397, check)
      call createCurrent(P_c, P_A, P_cAnti, 984, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 831, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 1069, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 1077, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 698, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 23, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 185, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 825, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 311, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 955, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 1046, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 243, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 928, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 812, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 4, check)
      call createCurrent(P_A, P_Z, P_H, 312, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 507, check)
      call createCurrent(P_Z, P_Z, P_G0, 672, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 403, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 643, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 746, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1203, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 223, check)
      call createCurrent(P_Z, P_A, P_H, 897, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 36, check)
      call createCurrent(P_bAnti, P_b, 1104, check)
      call createCurrent(P_g, P_g, P_g, 527, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 80, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 359, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 782, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 538, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 539, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 334, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 402, check)
      call createCurrent(P_Z, P_H, P_Z, 161, check)
      call createCurrent(P_tAnti, P_G0, P_t, 893, check)
      call createCurrent(P_A, P_tAnti, P_t, 156, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 401, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 583, check)
      call createCurrent(P_u, P_g, P_uAnti, 806, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 709, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 922, check)
      call createCurrent(P_t, P_tAnti, P_Z, 587, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 498, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 867, check)
      call createCurrent(P_tAnti, P_Z, P_t, 1076, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 947, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 1094, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 255, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 564, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 768, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 1091, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 372, check)
      call createCurrent(P_Z, P_d, P_dAnti, 701, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 572, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 880, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 932, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 771, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 412, check)
      call createCurrent(P_d, P_dAnti, P_H, 135, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 829, check)
      call createCurrent(P_c, P_cAnti, P_G0, 665, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1144, check)
      call createCurrent(P_G0, P_G0, P_A, 482, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 31, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 877, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 801, check)
      call createCurrent(P_b, P_bAnti, P_g, 1017, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, 388, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 272, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 180, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 1002, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 1016, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 263, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1200, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 1045, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1157, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 506, check)
      call createCurrent(P_A, P_s, P_sAnti, 652, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 689, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 261, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 868, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 735, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 528, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 1073, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 192, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 269, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1180, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 628, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 300, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 1053, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 859, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 784, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 378, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 856, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 447, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 999, check)
      call createCurrent(P_d, P_g, P_dAnti, 249, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 483, check)
      call createCurrent(P_g, P_t, P_tAnti, 612, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 213, check)
      call createCurrent(P_H, P_tAnti, P_t, 1047, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1122, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 604, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 987, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 286, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1196, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 647, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 770, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 256, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1188, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1177, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 929, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 485, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 422, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 28, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 237, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 424, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 576, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1006, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 56, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 244, check)
      call createCurrent(P_dAnti, P_d, P_A, 715, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 1070, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 477, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 961, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 797, check)
      call createCurrent(P_s, P_sAnti, P_G0, 39, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 924, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1179, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 55, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 641, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 607, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 934, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 369, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 420, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 752, check)
      call createCurrent(P_dAnti, P_d, P_H, 656, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 3, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 804, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 717, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 1033, check)
      call createCurrent(P_u, P_H, P_uAnti, 427, check)
      call createCurrent(P_G0, P_H, P_A, 356, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 1066, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 1059, check)
      call createCurrent(P_b, P_G0, P_bAnti, 218, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 303, check)
      call createCurrent(P_Z, P_tAnti, P_t, 502, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 876, check)
      call createCurrent(P_g, P_b, P_bAnti, 536, check)
      call createCurrent(P_A, P_b, P_bAnti, 581, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 1086, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 330, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 1003, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 524, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 66, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 886, check)
      call createCurrent(P_Z, P_t, P_tAnti, 72, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 221, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 253, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 148, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 419, check)
      call createCurrent(P_c, P_H, P_cAnti, 434, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 908, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 347, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 1079, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 861, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 793, check)
      call createCurrent(P_sAnti, P_s, P_g, 58, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 778, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 882, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1153, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 1083, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 589, check)
      call createCurrent(P_Z, P_c, P_cAnti, 141, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 1036, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 726, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 337, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 214, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 509, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 659, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1141, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 920, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 432, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1198, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 258, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1173, check)
      call createCurrent(P_b, P_g, P_bAnti, 790, check)
      call createCurrent(P_tAnti, P_t, P_g, 716, check)
      call createCurrent(P_A, P_G0, P_A, 565, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 17, check)
      call createCurrent(P_g, P_cAnti, P_c, 995, check)
      call createCurrent(P_d, P_H, P_dAnti, 751, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 428, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 951, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 42, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 21, check)
      call createCurrent(P_Z, P_H, P_A, 989, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 864, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 454, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 636, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 983, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 150, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 165, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 381, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, 662, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 503, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 167, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 176, check)
      call createCurrent(P_sAnti, P_s, P_G0, 194, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 903, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 30, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 333, check)
      call createCurrent(P_A, P_H, P_Z, 399, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 352, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 430, check)
      call createCurrent(P_c, P_cAnti, P_g, 273, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 1026, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 136, check)
      call createCurrent(P_u, P_G0, P_uAnti, 144, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 203, check)
      call createCurrent(P_cAnti, P_c, P_G0, 16, check)
      call createCurrent(P_G0, P_G0, 1134, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 839, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 140, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 458, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 208, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 733, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 997, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 681, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 742, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 29, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 406, check)
      call createCurrent(P_bAnti, P_b, P_g, 1025, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 648, check)
      call createCurrent(P_G0, P_sAnti, P_s, 95, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 438, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 1063, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 1039, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 664, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 41, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 497, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 205, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 142, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 905, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 239, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 634, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 129, check)
      call createCurrent(P_G0, P_Z, P_Z, 991, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 291, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 678, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 212, check)
      call createCurrent(P_H, P_u, P_uAnti, 489, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 24, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 535, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 209, check)
      call createCurrent(P_G0, P_A, P_H, 723, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 343, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 76, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 826, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 855, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 54, check)
      call createCurrent(P_H, P_A, P_G0, 682, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 970, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1155, check)
      call createCurrent(P_Z, P_Z, P_A, 154, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 189, check)
      call createCurrent(P_Z, P_G0, P_Z, 289, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 151, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 627, check)
      call createCurrent(P_cAnti, P_c, P_g, 233, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 1093, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 324, check)
      call createCurrent(P_H, P_c, P_cAnti, 550, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 69, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 762, check)
      call createCurrent(P_b, P_Z, P_bAnti, 878, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 57, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 367, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 638, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 936, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 146, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 423, check)
      call createCurrent(P_uAnti, P_u, P_A, 299, check)
      call createCurrent(P_g, P_dAnti, P_d, 569, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 615, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 251, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 465, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 580, check)
      call createCurrent(P_bAnti, P_b, P_H, 594, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 409, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 215, check)
      call createCurrent(P_A, P_bAnti, P_b, 516, check)
      call createCurrent(P_A, P_H, P_H, 1081, check)
      call createCurrent(P_t, P_tAnti, P_g, 843, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 679, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 268, check)
      call createCurrent(P_g, P_bAnti, P_b, 181, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 119, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 164, check)
      call createCurrent(P_b, P_bAnti, P_H, 952, check)
      call createCurrent(P_t, P_A, P_tAnti, 523, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 896, check)
      call createCurrent(P_G0, P_A, P_G0, 449, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 484, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 755, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 75, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 693, check)
      call createCurrent(P_G0, P_Z, P_H, 123, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 624, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1160, check)
      call createCurrent(P_cAnti, P_c, P_Z, 948, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 191, check)
      call createCurrent(P_Z, P_G0, P_A, 43, check)
      call createCurrent(P_G0, P_Z, P_A, 725, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 840, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 368, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 296, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 981, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 817, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 792, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 563, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 1015, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 240, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 392, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 957, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 639, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1008, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 911, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1150, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 332, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 481, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 433, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 505, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 881, check)
      call createCurrent(P_bAnti, P_b, P_A, 950, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 211, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 252, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 988, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 162, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 532, check)
      call createCurrent(P_muMinus, P_muPlus, 1136, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 874, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 637, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 1032, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 184, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 773, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 408, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 813, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 907, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1151, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 201, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 228, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 13, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 858, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 511, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 968, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 488, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 845, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 385, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 175, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 266, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1080, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1078, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 464, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 131, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1166, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1140, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, 853, check)
      call createCurrent(P_H, P_b, P_bAnti, 684, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 340, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1089, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 1065, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1123, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 629, check)
      call createCurrent(P_dAnti, P_G0, P_d, 686, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, 61, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 824, check)
      call createCurrent(P_A, P_A, 1158, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 236, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 250, check)
      call createCurrent(P_Z, P_H, P_G0, 339, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 366, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 413, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 998, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 308, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 568, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1147, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 1058, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 109, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 358, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 389, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 849, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 500, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 12, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 282, check)
      call createCurrent(P_tAnti, P_t, P_G0, 254, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 122, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 155, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 619, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 578, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 914, check)
      call createCurrent(P_tAnti, P_g, P_t, 781, check)
      call createCurrent(P_cAnti, P_G0, P_c, 453, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 749, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 515, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 739, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 469, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 945, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 302, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 541, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1011, check)
      call createCurrent(P_tAnti, P_t, P_H, 517, check)
      call createCurrent(P_u, P_uAnti, P_g, 738, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 556, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 320, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 586, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 943, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 226, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 182, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 400, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 547, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 870, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 1012, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 776, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, 584, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 44, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 822, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 363, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 127, check)
      call createCurrent(P_G0, P_b, P_bAnti, 866, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 120, check)
      call createCurrent(P_H, P_Z, P_H, 915, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 871, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 795, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 642, check)
      call createCurrent(P_Z, P_H, P_H, 616, check)
      call createCurrent(P_b, P_H, P_bAnti, 860, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 100, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 360, check)
      call createCurrent(P_uAnti, P_g, P_u, 19, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 178, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 1072, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 841, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1181, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 617, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 206, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 972, check)
      call createCurrent(P_H, P_s, P_sAnti, 279, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 847, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 174, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 387, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 575, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 631, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 1090, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 508, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 802, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 931, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1186, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 380, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 702, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 744, check)
      call createCurrent(P_tAnti, P_A, P_t, 49, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 93, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 630, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 774, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1182, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 803, check)
      call createCurrent(P_u, P_Z, P_uAnti, 525, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 766, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 590, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 1005, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 899, check)
      call createCurrent(P_H, P_Z, P_A, 820, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 830, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 887, check)
      call createCurrent(P_s, P_sAnti, P_A, 118, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 732, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 47, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 504, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 670, check)
      call createCurrent(P_dAnti, P_d, P_G0, 384, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(12)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(15)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else if(cc(4) .or. cc(5)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(20)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else if(cc(5) .or. cc(7)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(22)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else if(cc(4) .or. cc(5) .or. cc(6) .or. cc(7)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(24)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(25)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else if(cc(4) .or. cc(5) .or. cc(6) .or. cc(7)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(27)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3) .or. cc(4)) then
          mr = 2
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3) .or. cc(4)) then
          mr = 2
        else
          mr = 0
        end if 
      case(29)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else if(cc(4) .or. cc(5)) then
          mr = 1
        else
          mr = 0
        end if 
      case(30)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(31)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(32)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(33)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(34)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(35)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(36)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3) .or. cc(4)) then
          mr = 2
        else
          mr = 0
        end if 
      case(37)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(38)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(39)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(40)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 3
        else
          mr = 0
        end if 
      case(41)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(43)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(44)
        if (cc(0) .or. cc(1)) then
          mr = 3
        else
          mr = 0
        end if 
      case(45)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(46)
        if (cc(0) .or. cc(2) .or. cc(4)) then
          mr = 2
        else if(cc(1) .or. cc(3) .or. cc(5)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 3
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 3
        else
          mr = 0
        end if 
      case(49)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(73)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(74)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(1) .or. cc(3) .or. cc(5)) then
          mr = 2
        else if(cc(0) .or. cc(2) .or. cc(4)) then
          mr = 1
        else
          mr = 0
        end if 
      case(77)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 3
        else
          mr = 0
        end if 
      case(78)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(79)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(80)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 3
        else
          mr = 0
        end if 
      case(81)
        if (cc(0) .or. cc(1)) then
          mr = 3
        else
          mr = 0
        end if 
      case(82)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 3
        else
          mr = 0
        end if 
      case(83)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(84)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(85)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(86)
        if (cc(0) .or. cc(1)) then
          mr = 2
        else
          mr = 0
        end if 
      case(87)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(90)
        if (cc(0) .or. cc(1)) then
          mr = 2
        else
          mr = 0
        end if 
      case(91)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(92)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3)) then
          mr = 2
        else
          mr = 0
        end if 
      case(93)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(95)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(96)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(97)
        if (cc(0) .or. cc(1) .or. cc(2) .or. cc(3) .or. cc(4) .or. cc(5)) then
          mr = 1
        else
          mr = 0
        end if 
      case(98)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(99)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 2
        else
          mr = 0
        end if 
      case(100)
        if (cc(0) .or. cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(101)
        if (cc(0) .or. cc(1)) then
          mr = 2
        else
          mr = 0
        end if 
      case(105)
        if (cc(0) .or. cc(1)) then
          mr = 2
        else
          mr = 0
        end if 
      case(106)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(108)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(111)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(112)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(114)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
